@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import logging
-
 from django import shortcuts
 from django.utils.translation import ugettext_lazy as _
 
@@ -24,29 +22,24 @@ from horizon import workflows
 import disaster_recovery.api.api as freezer_api
 
 
-LOG = logging.getLogger(__name__)
-
-
 class ActionConfigurationAction(workflows.Action):
     action_id = forms.CharField(
         widget=forms.HiddenInput(),
         required=False)
 
+    backup_name = forms.CharField(
+        label=_("Action Name *"),
+        required=False)
+
     action = forms.ChoiceField(
-        help_text=_("Set the action to be taken"),
-        required=True)
+        help_text=_("Set the action to be taken"))
 
     mode = forms.ChoiceField(
         help_text=_("Choose what you want to backup"),
         required=False)
 
     storage = forms.ChoiceField(
-        help_text=_("Set storage backend for a backup"),
-        required=True)
-
-    backup_name = forms.CharField(
-        label=_("Action Name *"),
-        required=False)
+        help_text=_("Set storage backend for a backup"))
 
     mysql_conf = forms.CharField(
         label=_("MySQL Configuration File *"),
@@ -66,7 +59,7 @@ class ActionConfigurationAction(workflows.Action):
         required=False)
 
     container = forms.CharField(
-        label=_("Container Name or Path *"),
+        label=_("Container Name or Path"),
         help_text=_("Swift container for swift backend or "
                     "path for ssh or local backend"),
         required=False)
@@ -104,10 +97,15 @@ class ActionConfigurationAction(workflows.Action):
         required=False)
 
     nova_inst_id = forms.CharField(
-        label=_("Nova Volume ID *"),
+        label=_("Nova Instance ID *"),
         help_text=_("Id of nova instance for backup"),
         required=False)
 
+    nova_network_id = forms.CharField(
+        label=_("Nova network ID *"),
+        help_text=_("Id of nova network for recover"),
+        required=False)
+
     get_object = forms.CharField(
         label=_("Get A Single Object"),
         help_text=_("The Object name you want to download on "
@@ -165,17 +163,33 @@ class ActionConfigurationAction(workflows.Action):
                 self._check_backup_name(cleaned_data)
                 return cleaned_data
 
-            self._check_container(cleaned_data)
             self._check_backup_name(cleaned_data)
             self._check_path_to_backup(cleaned_data)
 
-        elif cleaned_data.get('action') == 'restore':
+        elif cleaned_data.get('action') == 'restore' \
+                and cleaned_data.get('mode') == 'fs':
             self._check_container(cleaned_data)
             self._check_backup_name(cleaned_data)
             self._check_restore_abs_path(cleaned_data)
+        elif cleaned_data.get('action') == 'restore' \
+                and cleaned_data.get('mode') == 'nova':
+            self._check_container(cleaned_data)
+            self._check_backup_name(cleaned_data)
+            self._check_nova_inst_id(cleaned_data)
+            self._check_nova_network_id(cleaned_data)
 
         return cleaned_data
 
+    def _check_nova_network_id(self, cleaned_data):
+        if not cleaned_data.get('nova_network_id'):
+            msg = _("You must define nova network id to restore.")
+            self._errors['nova_inst_id'] = self.error_class([msg])
+
+    def _check_nova_inst_id(self, cleaned_data):
+        if not cleaned_data.get('nova_inst_id'):
+            msg = _("You must define nova instance id to restore.")
+            self._errors['nova_inst_id'] = self.error_class([msg])
+
     def _check_restore_abs_path(self, cleaned_data):
         if not cleaned_data.get('restore_abs_path'):
             msg = _("You must define a path to restore.")
@@ -228,7 +242,7 @@ class ActionConfigurationAction(workflows.Action):
 
     class Meta(object):
         name = _("Action")
-        help_text_template = "disaster_recovery/jobs" \
+        help_text_template = "disaster_recovery/actions" \
                              "/_action.html"
 
 
@@ -248,6 +262,7 @@ class ActionConfiguration(workflows.Step):
                    'restore_from_date',
                    'cinder_vol_id',
                    'nova_inst_id',
+                   'nova_network_id',
                    'get_object',
                    'dst_file',
                    'remove_older_than',
@@ -268,7 +283,7 @@ class SnapshotConfigurationAction(workflows.Action):
 
     class Meta(object):
         name = _("Snapshot")
-        help_text_template = "disaster_recovery/jobs" \
+        help_text_template = "disaster_recovery/actions" \
                              "/_snapshot.html"
 
 
@@ -453,7 +468,7 @@ class AdvancedConfigurationAction(workflows.Action):
 
     class Meta(object):
         name = _("Advanced")
-        help_text_template = "disaster_recovery/jobs" \
+        help_text_template = "disaster_recovery/actions" \
                              "/_advanced.html"
 
 
@@ -493,19 +508,19 @@ class RulesConfigurationAction(workflows.Action):
         label=_("Max Retries Interval"),
         initial=0,
         min_value=0,
-        help_text=_("Set the interval between intervals "
+        help_text=_("Set the interval between executions "
                     "for retries in seconds"),
         required=False)
 
     mandatory = forms.BooleanField(
         label=_("Mandatory"),
-        help_text=_("Set this job as mandatory"),
+        help_text=_("Set this action as mandatory"),
         widget=forms.CheckboxInput(),
         required=False)
 
     class Meta(object):
         name = _("Rules")
-        help_text_template = "disaster_recovery/jobs" \
+        help_text_template = "disaster_recovery/actions" \
                              "/_rules.html"
 
 
@@ -520,7 +535,7 @@ class ActionWorkflow(workflows.Workflow):
     slug = "action"
     name = _("Action Configuration")
     finalize_button_name = _("Save")
-    success_message = _('Action file saved correctly.')
+    success_message = _('Action queued correctly. It will appear soon')
     failure_message = _('Unable to save action file.')
     success_url = "horizon:disaster_recovery:actions:index"
 
