@@ -13,17 +13,16 @@
 # Some helper functions to use the disaster_recovery client functionality
 # from horizon.
 
-import logging
+from oslo_log import log
 
 from django.conf import settings
-
 from horizon.utils.memoized import memoized  # noqa
+from freezerclient.v1 import client as freezer_client
 
-import freezer.apiclient.client
 from disaster_recovery import utils
 
 
-LOG = logging.getLogger(__name__)
+LOG = log.getLogger(__name__)
 
 
 @memoized
@@ -35,11 +34,14 @@ def client(request):
     ks_version = getattr(settings,
                          'OPENSTACK_API_VERSIONS', {}).get('identity', 2.0)
 
+    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+
     credentials = {
         'token': request.user.token.id,
         'auth_url': getattr(settings, 'OPENSTACK_KEYSTONE_URL'),
         'endpoint': api_url,
-        'version': ks_version
+        'version': ks_version,
+        'cert': cacert
     }
 
     if ks_version == 3:
@@ -47,46 +49,72 @@ def client(request):
         credentials['project_domain_name'] = \
             request.user.domain_name or 'Default'
 
-    return freezer.apiclient.client.Client(**credentials)
+    return freezer_client.Client(**credentials)
 
 
 @memoized
 def _get_service_url(request):
     """Get freezer api url"""
-    catalog = (getattr(request.user, "service_catalog", None))
-    if not catalog:
-        return _get_hardcoded_url()
+    hardcoded_url = getattr(settings, 'FREEZER_API_URL', None)
+    if hardcoded_url is not None:
+        LOG.warning('Using hardcoded FREEZER_API_URL:{0}'
+                    .format(hardcoded_url))
+        return hardcoded_url
 
-    for c in catalog:
-        if c['name'] == 'freezer':
-            for e in c['endpoints']:
-                return e['internalURL']
-    else:
-        return _get_hardcoded_url()
+    e_type = getattr(settings, 'OPENSTACK_ENDPOINT_TYPE', '')
+    endpoint_type_priority = [e_type, ['internal', 'internalURL'], ['public',
+                              'publicURL']]
 
-
-@memoized
-def _get_hardcoded_url():
-    """In case freezer is not registered in keystone catalog, look for it in
-    local_settings.py
-    :return: freezer_api_url
-    """
     try:
-        LOG.warn('Using hardcoded FREEZER_API_URL at {0}'
-                 .format(settings.FREEZER_API_URL))
-        return getattr(settings, 'FREEZER_API_URL', None)
+        catalog = (getattr(request.user, "service_catalog", []))
+        for c in catalog:
+            if c['name'] == 'freezer':
+                for endpoint_type in endpoint_type_priority:
+                    for e in c['endpoints']:
+                        if e['interface'] in endpoint_type:
+                            return e['url']
+        raise ValueError('Could no get FREEZER_API_URL from config'
+                         ' or Keystone')
     except Exception:
-        LOG.warn('No FREEZER_API_URL was found in local_settings.py')
+        LOG.warning('Could no get FREEZER_API_URL from config or Keystone')
         raise
 
 
+def get_schedule_info(context):
+    """Get schedule info from context
+    """
+    scheduling = {}
+    try:
+        if context['schedule_end_date'] != '':
+            utils.assign_and_remove(context, scheduling, 'schedule_end_date')
+        else:
+            context.pop('schedule_end_date')
+    except KeyError:
+        pass
+    try:
+        if context['schedule_interval'] != '':
+            utils.assign_and_remove(context, scheduling, 'schedule_interval')
+        else:
+            context.pop('schedule_interval')
+    except KeyError:
+        pass
+    try:
+        if context['schedule_start_date'] != '':
+            utils.assign_and_remove(context, scheduling, 'schedule_start_date')
+        else:
+            context.pop('schedule_start_date')
+    except KeyError:
+        pass
+    return scheduling
+
+
 class Job(object):
 
     def __init__(self, request):
         self.request = request
         self.client = client(request)
 
-    def list(self, json=False, limit=100, offset=0, search=None):
+    def list(self, json=False, limit=500, offset=0, search=None):
         if search:
             search = {"match": [{"_all": search}, ], }
 
@@ -100,7 +128,7 @@ class Job(object):
             job.get('job_id'),
             job.get('description'),
             job.get('job_schedule', {}).get('result'),
-            job.get('job_schedule', {}).get('event'),
+            job.get('job_schedule', {}).get('status'),
             job.get('client_id')
         ) for job in jobs]
 
@@ -121,31 +149,7 @@ class Job(object):
         return self._build(job)
 
     def update(self, job_id, job):
-        scheduling = {}
-        try:
-            if job['schedule_end_date'] != '':
-                utils.assign_and_remove(job, scheduling, 'schedule_end_date')
-            else:
-                job.pop('schedule_end_date')
-        except KeyError:
-            pass
-
-        try:
-            if job['schedule_interval'] != '':
-                utils.assign_and_remove(job, scheduling, 'schedule_interval')
-            else:
-                job.pop('schedule_interval')
-        except KeyError:
-            pass
-
-        try:
-            if job['schedule_start_date'] != '':
-                utils.assign_and_remove(job, scheduling, 'schedule_start_date')
-            else:
-                job.pop('schedule_start_date')
-        except KeyError:
-            pass
-
+        scheduling = get_schedule_info(job)
         job.pop('job_actions', [])
         job.pop('clients', None)
         job.pop('actions', None)
@@ -232,11 +236,7 @@ class Job(object):
         actions_in_job = []
         for action_id in action_ids:
             action = Action(self.request).get(action_id, json=True)
-            a = {
-                'action_id': action['action_id'],
-                'freezer_action': action['freezer_action']
-            }
-            actions_in_job.append(a)
+            actions_in_job.append(action)
         return actions_in_job
 
 
@@ -246,7 +246,7 @@ class Session(object):
         self.request = request
         self.client = client(request)
 
-    def list(self, json=False, limit=30, offset=0, search=None):
+    def list(self, json=False, limit=500, offset=0, search=None):
         if search:
             search = {"match": [{"_all": search}, ], }
 
@@ -286,7 +286,9 @@ class Session(object):
         return self._build(session)
 
     def update(self, session, session_id):
-        return self.client.sessions.update(session_id, session)
+        new_session = {'schedule': get_schedule_info(session),
+                       'description': session.pop('description')}
+        return self.client.sessions.update(session_id, new_session)
 
     def delete(self, session_id):
         return self.client.sessions.delete(session_id)
@@ -336,7 +338,7 @@ class Action(object):
         self.request = request
         self.client = client(request)
 
-    def list(self, json=False, limit=100, offset=0, search=None):
+    def list(self, json=False, limit=500, offset=0, search=None):
         if search:
             search = {"match": [{"_all": search}, ], }
 
@@ -351,8 +353,8 @@ class Action(object):
             action.get('action_id'),
             action['freezer_action'].get('action'),
             action['freezer_action'].get('backup_name'),
-            action['freezer_action'].get('path_to_backup')
-            or action['freezer_action'].get('restore_abs_path'),
+            action['freezer_action'].get('path_to_backup') or
+            action['freezer_action'].get('restore_abs_path'),
             action['freezer_action'].get('storage'),
             mode=action['freezer_action'].get('mode')
         ) for action in actions]
@@ -425,13 +427,13 @@ class Client(object):
         self.request = request
         self.client = client(request)
 
-    def list(self, json=False, limit=100, offset=0, search=None):
+    def list(self, json=False, limit=500, offset=0, search=None):
         if search:
             search = {"match": [{"_all": search}, ], }
 
-        clients = self.client.registration.list(limit=limit,
-                                                offset=offset,
-                                                search=search)
+        clients = self.client.clients.list(limit=limit,
+                                           offset=offset,
+                                           search=search)
 
         if json:
             return clients
@@ -443,7 +445,7 @@ class Client(object):
         ) for c in clients]
 
     def get(self, client_id, json=False):
-        c = self.client.registration.get(client_id)
+        c = self.client.clients.get(client_id)
 
         if json:
             return c
@@ -454,7 +456,7 @@ class Client(object):
             c.get('uuid'))
 
     def delete(self, client_id):
-        return self.client.registration.delete(client_id)
+        return self.client.clients.delete(client_id)
 
 
 class Backup(object):
@@ -463,7 +465,7 @@ class Backup(object):
         self.request = request
         self.client = client(request)
 
-    def list(self, json=False, limit=30, offset=0, search=None):
+    def list(self, json=False, limit=500, offset=0, search={}):
         if search:
             search = {"match": [{"_all": search}, ], }
 
@@ -475,7 +477,7 @@ class Backup(object):
             return backups
 
         return [utils.BackupObject(
-            backup_id=b.get('backup_uuid'),
+            backup_id=b.get('backup_id'),
             action=b.get('backup_metadata', {}).get('action'),
             time_stamp=b.get('backup_metadata', {}).get('time_stamp'),
             backup_name=b.get('backup_metadata', {}).get('backup_name'),
@@ -500,7 +502,7 @@ class Backup(object):
 
     def get(self, backup_id, json=False):
 
-        search = {"match": [{"backup_uuid": backup_id}, ], }
+        search = {"match": [{"backup_id": backup_id}, ], }
 
         b = self.client.backups.list(limit=1, search=search)
         b = b[0]
@@ -509,7 +511,7 @@ class Backup(object):
             return b
 
         return utils.BackupObject(
-            backup_id=b.get('backup_uuid'),
+            backup_id=b.get('backup_id'),
             action=b.get('backup_metadata', {}).get('action'),
             time_stamp=b.get('backup_metadata', {}).get('time_stamp'),
             backup_name=b.get('backup_metadata', {}).get('backup_name'),
